@@ -83,12 +83,19 @@
 #define VMW_INNERSTRINGIFY(s) #s
 #define VMW_STRING(str) VMW_INNERSTRINGIFY(str)
 
+/*
+ * So that the file compiles unmodified when dropped into an xfree source tree.
+ */
+#ifndef XORG_VERSION_CURRENT
+#define XORG_VERSION_CURRENT XF86_VERSION_CURRENT
+#endif
+
 /*
  * Version constants
  */
 #define VMMOUSE_MAJOR_VERSION 12
 #define VMMOUSE_MINOR_VERSION 4
-#define VMMOUSE_PATCHLEVEL 2
+#define VMMOUSE_PATCHLEVEL 3
 #define VMMOUSE_DRIVER_VERSION \
    (VMMOUSE_MAJOR_VERSION * 65536 + VMMOUSE_MINOR_VERSION * 256 + VMMOUSE_PATCHLEVEL)
 #define VMMOUSE_DRIVER_VERSION_STRING \
@@ -101,7 +108,7 @@
  * extra zero for the fourth digit.
  */
 #ifdef __GNUC__
-const char vm_version[] __attribute__((section(".modinfo"),unused)) =
+const char vm_mouse_version[] __attribute__((section(".modinfo"),unused)) =
     "version=" VMMOUSE_DRIVER_VERSION_STRING ".0";
 #endif
 
@@ -483,7 +490,13 @@ VMMouseDoPostEvent(InputInfoPtr pInfo, int buttons, int dx, int dy)
     buttons = reverseBits(reverseMap, buttons);
 
     if (dx || dy) {
-       xf86PostMotionEvent(pInfo->dev, !mPriv->relative, 0, 2, dx, dy);
+
+        /*
+         * The Xserver no longer calls an input device's conversion_proc
+         * to convert x and y coordinates from device to screen space.
+         */
+        VMMouseConvertProc(pInfo, 0, 2, dx, dy, 0, 0, 0, 0, &dx, &dy);
+        xf86PostMotionEvent(pInfo->dev, !mPriv->relative, 0, 2, dx, dy);
     }
     
     if (truebuttons != pMse->lastButtons) {
